


/*
 * This is a template file. It defines integration functions necessary to complete RTA-BSW.
 * The integrator must complete the templates before deploying software containing functions defined in this file.
 * Once templates have been completed, the integrator should delete the #error line.
 * Note: The integrator is responsible for updates made to this file.
 *
 * To remove the following error define the macro NOT_READY_FOR_TESTING_OR_DEPLOYMENT with a compiler option (e.g. -D NOT_READY_FOR_TESTING_OR_DEPLOYMENT)
 * The removal of the error only allows the user to proceed with the building phase
 */
/* #ifndef NOT_READY_FOR_TESTING_OR_DEPLOYMENT
#error The content of this file is a template which provides empty stubs. The content of this file must be completed by the integrator accordingly to project specific requirements
#else
#warning The content of this file is a template which provides empty stubs. The content of this file must be completed by the integrator accordingly to project specific requirements
#endif */ /* NOT_READY_FOR_TESTING_OR_DEPLOYMENT */


#ifndef DEM_PRJSPECIFICFFHANDLING_H
#define DEM_PRJSPECIFICFFHANDLING_H

/**
 * \file
 * \ingroup DEM_PRJ_TPL
 * \brief Custom condition when freeze frames shall be stored
 *
 * If DemRbProjectSpecificFFHandling is enabled, this method will replace the Dem-internal function to decide whether
 * a freeze frame should be captured.
 */

/**
 * \brief Decide whether a freeze frame should be stored
 *
 * Is called when the event is distributed to the event memory and decides if a new freeze frame should be stored.
 *
 * \param EventId    The ID of the event
 * \param MemId      Id of the event memory where the event is stored (primary, secondary or mirror)
 * \param StatusOld  The old status byte stored in the event memory
 * \param StatusNew  The new status byte that will be stored in the event memory
 */
DEM_INLINE Dem_boolean_least Dem_EvMemIsTriggerFreezeFrame(Dem_EventIdType EventId, uint16_least MemId, uint16_least StatusOld, uint16_least StatusNew)
{
	/*Write project specific code here*/
}

#endif /* INCLUDE_PROTECTION */
